/*
 * @Company: hugeInfo
 * @Author: lwh
 * @Date: 2024-09-14 15:59:17
 * @LastEditTime: 2025-06-14 11:35:43
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description:
 */
import React, { useState, useEffect, useRef, useMemo } from 'react';
import * as $$ from '../../utils/utility';
import { Form, Typography, Row, Col, Space } from 'antd';
import { useLocation, useNavigate, useSearchParams } from 'react-router-dom';
import { IconUndo } from '@arco-design/web-react/icon';
import {
	disputeLedger_1,
	disputeLedger_2,
	disputeLedger_3,
	disputeLedger_4,
	disputeLedger_5,
	disputeLedger_6,
	disputeLedger_7,
	disputeLedger_8,
	disputeLedger_9,
	disputeLedger_10,
	disputeLedger_11,
	disputeLedger_12,
	disputeLedger_13,
	disputeLedger_14,
} from '../../assets/images';
import NewPage from '../../components/NewPage/index';
import * as echarts from 'echarts';
import NewTableSearch from '../../components/NewTableSearch';
import './index.less';

const { Link } = Typography;

// 调度中心列表
function getMyMediationDataApi(submitData) {
	return $$.ax.request({ url: 'caseDisp/pageQuery', type: 'get', data: submitData, service: 'disp' });
}

// 调度中心列表
function getListDataApi(submitData) {
	return $$.ax.request({ url: 'caseInfo/ledger', type: 'get', data: submitData, service: 'mediate' });
}

// 区域字典值
function treeByUserIdApi(submitData) {
	return $$.ax.request({ url: 'syRegion/treeByUserId', type: 'get', data: submitData, service: 'sys' });
}

// 获取列表分类tab
function getTabsDataApi() {
	return $$.ax.request({ url: 'caseDisp/getApplyCanal', type: 'get', service: 'disp' });
}

// 纠纷类型子集
function statisticsCaseTypeApi(submitData) {
	return $$.ax.request({ url: 'caseInfo/statisticsCaseType', type: 'get', data: submitData, service: 'mediate' });
}

const DisputeLedger = () => {
	const [form] = Form.useForm();
	// 数据汇总选择
	const [activeKey, setActiveKey] = useState(1);
	const [activeName, setActiveName] = useState('本系统');
	const [tabsData, setTabsData] = useState();

	// 区域字典值
	const [treeList, setTreeList] = useState([]);

	// 默认查询询条件
	const [normalSearch, setNormalSearch] = useState({});

	// 纠纷类型饼图所在层级
	const [caseTypeLevel, setCaseTypeLevel] = useState(1);

	// 纠纷类型饼图2层，3层数据
	const [caseTypeList, setCaseTypeList] = useState([]);

	const [data, setData] = useState({
		data2: { value1: '4759', value2: '1022', value3: '1006', value4: '2201', value5: '221', value6: '98', value7: '432' },
		data1: { value1: '22', value2: '28', value3: '15', value4: '10', value5: '5', value6: '20' },
		data3: [4759, 430, 310, 49, 996, 2210, 109, 230, 110, 25, 56, 355],
		data4: { value1: 24, value2: 30, value3: 46 },
	});

	const [allNum, setAllNum] = useState(0);

	// 搜索 or 重置
	function handleSearch(type, session) {
		if (type === 'reset') {
			if (session) {
				getListData(
					{
						[session.key]: session.value[0],
						createStart: $$.dateFormat(session.createStart),
						createEnd: $$.dateFormat(session.createEnd),
					},
					activeKey
				);
			} else {
				getListData(
					{
						[normalSearch.key]: normalSearch.value[0],
						createStart: $$.dateFormat(normalSearch.createStart),
						createEnd: $$.dateFormat(normalSearch.createEnd),
					},
					activeKey
				);
			}
			return;
		}
		if (type === 'search') {
			let values = form.getFieldsValue();
			$$.changeTimNeweFormat(values, 'createTime', 'createStart', 'createEnd');
			$$.changeTimNeweFormat(values, 'endTime', 'closeStart', 'closeEnd');
			$$.searchCascader(values, 'queCode', normalSearch.level, ['queCity', 'queArea', 'queRoad', 'queVillage']);
			$$.searchCascader(values, 'caseType', 1, ['caseType', 'caseType']);
			getListData({ ...values }, session);
			return;
		}
	}

	// 获取数据
	async function getListData(submitData, ledgerType) {
		global.setSpinning(true);
		const res = await getListDataApi({ ...submitData, ledgerType });
		global.setSpinning(false);
		if (res.type) {
			let nowData = res.data || {};
			setData({ ...data, ...nowData });
			// setSearch(submitData);
		}
	}

	// 饼图点击进入下一层级
	async function onMyLTopChartPie(params) {
		let caseTypeFirst = params?.data?.caseType;
		global.setSpinning(true);
		const res = await statisticsCaseTypeApi({ caseTypeFirst });
		global.setSpinning(false);
		if (res.type) {
			setCaseTypeList(res.data || []);
			setCaseTypeLevel(caseTypeLevel + 1);
		}
	}

	// 获取区域字典值
	async function treeByUserId() {
		global.setSpinning(true);
		const res = await treeByUserIdApi();
		global.setSpinning(false);
		if (res.type) {
			let list = res.data || [];
			setTreeList(list);
			let values = form.getFieldsValue();
			let key = levelKey(list[0].level || '1');
			values.queCode = [list[0].value];
			values.createTime = [
				$$.myMoment().subtract(0, 'months').startOf('month').format('YYYY-MM-DD'),
				$$.myMoment().subtract(0, 'months').endOf('month').format('YYYY-MM-DD'),
			];
			form.setFieldsValue(values);
			setNormalSearch({
				key,
				value: [list[0].value],
				level: list[0].level,
				createStart: $$.myMoment().subtract(0, 'months').startOf('month').format('YYYY-MM-DD'),
				createEnd: $$.myMoment().subtract(0, 'months').endOf('month').format('YYYY-MM-DD'),
			});
			handleSearch('reset', {
				key,
				value: [list[0].value],
				createStart: $$.myMoment().subtract(0, 'months').startOf('month').format('YYYY-MM-DD'),
				createEnd: $$.myMoment().subtract(0, 'months').endOf('month').format('YYYY-MM-DD'),
			});
		}
	}

	function levelKey(KeyIndex) {
		return {
			1: 'queCity',
			2: 'queArea',
			3: 'queRoad',
			4: 'queVillage',
		}[KeyIndex];
	}

	useEffect(() => {
		treeByUserId();
	}, []);

	return (
		<NewPage pageHead={{ breadcrumbData: [{ title: '工作台' }, { title: '纠纷台账' }], title: '纠纷台账' }}>
			<div className="comprehensive">
				<div className="pageSearch">
					<div className="comprehensive-title">查询条件</div>
					<NewTableSearch
						exportButtonShow={false}
						labelLength={6}
						rowNum={4.5}
						form={form}
						itemData={[
							{
								type: 'Cascader',
								name: 'queCode',
								label: '区域',
								placeholder: '请选择',
								changeSelect: true,
								allowClear: false,
								treedata: treeList || [],
							},
							{
								type: 'RangePicker',
								name: 'createTime',
								label: '登记时间',
								shortcutsPlacementLeft: true,
								allowClear: false,
								shortcuts: $$.shortcutsList(),
								span: 8,
							},
							{ type: 'RangePicker', name: 'endTime', label: '办结时间', shortcutsPlacementLeft: true, shortcuts: $$.shortcutsList(), span: 8 },
							{
								type: 'Cascader',
								name: 'caseType',
								label: '纠纷类型',
								placeholder: '请选择',
								changeSelect: true,
								span: 8,
								treedata: $$.caseTypeSelect.caseTypeSelect,
							},
							{
								type: 'Select',
								name: 'mediResult',
								label: '化解结果',
								placeholder: '请选择',
								span: 8,
								selectdata: [
									{ label: '化解中', value: '1' },
									{ label: '化解成功', value: '22_00025-1' },
									{ label: '化解不成功', value: '22_00025-2' },
								],
							},
							{
								type: 'Select',
								name: 'majorStatus',
								label: '是否重大矛盾',
								placeholder: '请选择',
								span: 8,
								selectdata: [
									{ label: '是', value: '1' },
									{ label: '否', value: '0' },
								],
							},
							{
								type: 'Select',
								name: 'name4',
								label: '重点人员',
								placeholder: '请选择',
								span: 8,
								selectdata: [{ label: '不限', value: '1' }],
							},
						]}
						handleReset={() => {
							form.resetFields();
							form.setFieldsValue({
								queCode: [normalSearch.value[0]],
								createTime: [$$.dateFormat(normalSearch.createStart), $$.dateFormat(normalSearch.createEnd)],
							});
							handleSearch('reset', normalSearch);
						}}
						handleSearch={() => handleSearch('search', activeKey || 1)}
					/>
				</div>
				<div className="disputeLedger-row">
					<div className="comprehensive-title">数据汇总</div>
					<div className="disputeLedger-d">
						{[
							{
								icon: disputeLedger_8,
								title: '全部',
								value: data?.totalNum || 0,
								backgroundColor: '#e8f7ff',
								borderColor: '#3491fa',
								color: '#3491FA',
								active: true,
							},
							{
								icon: disputeLedger_9,
								title: '本系统',
								value: data?.sysNum || 0,
								backgroundColor: '#fff7e6',
								borderColor: '#FA8C16',
								color: '#FA8C16',
								per: `${data?.sysRate || 0}%`,
							},
							{
								icon: disputeLedger_10,
								title: '12345',
								value: data?.ottffNum || 0,
								backgroundColor: '#F9F0FF',
								borderColor: '#722ED1',
								color: '#722ED1',
								per: `${data?.ottffRate || 0}%`,
							},
							{
								icon: disputeLedger_11,
								title: '非警务纠纷',
								value: data?.fjwjfNum || 0,
								backgroundColor: 'rgba(182,221,241,0.24)',
								borderColor: '#1A6FB8',
								color: '#1A6FB8',
								per: `${data?.fjwjfRate || 0}%`,
							},
							{
								icon: disputeLedger_12,
								title: '人民调解',
								value: data?.rmtjNum || 0,
								backgroundColor: 'rgba(253,205,197,0.24)',
								borderColor: '#F53F3F',
								color: '#F53F3F',
								per: `${data?.rmtjRate || 0}%`,
							},
							{
								icon: disputeLedger_13,
								title: '信访',
								value: data?.xfNum || 0,
								backgroundColor: 'rgba(175,240,181,0.24)',
								borderColor: '#00B42A',
								color: '#00B42A',
								per: `${data?.xfRate || 0}%`,
							},
							{
								icon: disputeLedger_14,
								title: '劳动争议',
								value: data?.ldzcNum || 0,
								backgroundColor: 'rgba(181,245,236,0.24)',
								borderColor: '#08979c',
								color: '#08979c',
								per: `${data?.ldzcRate || 0}%`,
							},
						].map((item, index) => (
							<div
								onClick={() => {
									setActiveKey(index);
									setActiveName(item.title);
									if (index === 0) {
										setAllNum(data?.allNum || 0);
										handleSearch('search', '');
									} else if (index === 1) {
										setAllNum(data?.sysNum || 0);
										handleSearch('search', 1);
									} else if (index === 2) {
										setAllNum(data?.ottffNum || 0);
										handleSearch('search', 2);
									} else if (index === 3) {
										setAllNum(data?.rmtjNum || 0);
										handleSearch('search', 3);
									} else if (index === 4) {
										setAllNum(data?.xfNum || 0);
										handleSearch('search', 4);
									} else if (index === 5) {
										setAllNum(data?.ldzcNum || 0);
										handleSearch('search', 5);
									} else if (index === 6) {
										setAllNum(data?.fjwjfNum || 0);
										handleSearch('search', 6);
									}
								}}
								className={`disputeLedger-card ${activeKey === index ? 'disputeLedger-card-active' : ''}`}
								style={{
									backgroundColor: item.backgroundColor,
									color: item.color,
									border: activeKey === index ? `1px solid ${item.borderColor}` : 'none',
									height: activeKey === index && '92px',
									display: 'flex',
									alignItems: 'center',
								}}
								span={3.4}
								key={index}
							>
								<div>
									<div className="disputeLedger-card-content">
										<div className={`disputeLedger-card-content-t`}>{item.title}</div>
										<div>
											<span className={`disputeLedger-card-title`}>{item.value}</span> <span className={`disputeLedger-unit`}>件</span>{' '}
											{item.per && <span className={`disputeLedger-unit `}>| {item.per}</span>}
										</div>
									</div>
									<img src={item.icon} style={{ width: activeKey === index && '52px', height: activeKey === index && '52px' }} alt="" />
								</div>
							</div>
						))}
					</div>
				</div>

				{/* 图表 */}
				<div className="disputeLedger-green">
					<div style={{ display: 'flex', flexDirection: 'column', gap: 12, marginBottom: '12px' }}>
						<Space className="big-green-main-space" direction="vertical">
							<div style={{ margin: '0 12px' }}>
								<div className="workDash-main-flex_1">
									<div style={{ alignItems: 'center', justifyContent: 'space-between' }} className="big-green-main-title-display">
										<div className="disputeLedger-green-title">纠纷类型（{activeName}）</div>
										{caseTypeLevel > 1 && (
											<div
												onClick={() => {
													setCaseTypeLevel(caseTypeLevel - 1);
												}}
												className="public-a"
												style={{ padding: '12px 16px' }}
											>
												<IconUndo style={{ color: '#1A6FB8' }} /> <span className=" public-color">返回上一级</span>
											</div>
										)}
									</div>
									{/* <div className='disputeLedger-green-title'>纠纷类型</div> */}
									<div style={{ paddingBottom: '12px' }}>
										<MyLTopChartPie
											onMyLTopChartPie={onMyLTopChartPie}
											data={
												caseTypeLevel > 1
													? caseTypeList?.map((i) => ({ value: i.caseRate, caseNum: i.caseNum, name: i.caseTypeName, caseType: i.caseType })) || []
													: data?.typeList?.map((i) => ({ value: i.caseRate, caseNum: i.caseNum, name: i.caseTypeName, caseType: i.caseType })) || []
											}
										/>
									</div>
								</div>
							</div>
						</Space>
						<Space style={{ position: 'relative' }} className="big-green-main-space" direction="vertical">
							<div style={{ margin: '0 12px' }}>
								<div className="disputeLedger-green-title">化解状况（{activeName}）</div>
								<div style={{ paddingBottom: '12px' }}>
									<MyLTopChartPie1
										data={[
											{ value: data.rejectNum, name: '不予受理' },
											{ value: data.processNum, name: '化解中' },
											{ value: data.finishNum, name: '化解成功' },
											{ value: data.failNum, name: '化解不成功' },
										]}
										allNum={allNum}
									/>
								</div>
							</div>
						</Space>
					</div>
					<Space style={{ flex: '1', marginBottom: '12px' }} className="big-green-main-space" direction="vertical">
						<div className="big-green-main-title-display">
							<div className="disputeLedger-green-title">区域统计（{activeName}）</div>
						</div>
						<div style={{ width: '100%', height: '200px', marginTop: '12px' }}>
							<MyChartBar
								data={activeKey === 0 ? data?.areaList?.map((i) => i.caseNum) || [] : data?.areaList?.map((i) => i.caseNum) || []}
								dataAxis={data?.areaList?.map((i) => i.areaName) || []}
							/>
						</div>
					</Space>
				</div>
			</div>
		</NewPage>
	);
};

export default DisputeLedger;

// 柱状图
const MyChartBar = ({ data, dataAxis }) => {
	const myChartRef = useRef();
	// 图表
	const [myChart, setMyChart] = useState();

	// 加载图表数据
	useEffect(() => {
		var myChart = echarts.init(document.getElementById('chartBar'), 'dark');

		// 绘制图表
		myChart.setOption({
			backgroundColor: '#fff',
			grid: {
				x: 10,
				y: 20,
				x2: 20,
				y2: 0,
				containLabel: true,
			},
			tooltip: {
				trigger: 'item',
				formatter: '{a} <br/>{b}: {c}件',
			},

			xAxis: [
				{
					type: 'category',
					// boundaryGap: false,
					data: dataAxis,

					axisLabel: {
						interval: 'auto', // 自动旋转标签
						rotate: 45,
						color: '#4e5969',
					},
					scrollbar: {
						show: true, // 显示滚动条
					},
				},
			],
			yAxis: {
				splitLine: {
					lineStyle: {
						type: 'dashed',
						color: '#ccc',
					},
				},
			},
			series: [
				{
					type: 'bar',
					name: '总登记',
					stack: 'one',
					barWidth: 24, // 柱子宽度
					label: {
						show: true,
						color: 'rgba(0, 0, 0, 0.85)',
						fontSize: '14px',
						position: 'top',
						valueAnimation: false,
					},
					emphasis: {
						itemStyle: {
							opacity: 0.7,
						},
					},
					itemStyle: {
						color: '#57a9fb',
						borderWidth: 2, // 设置边框宽度
					},
					data: data,
				},
			],
		});
	}, [data]);

	useEffect(() => {
		// if (myChart && myChartRef.current.clientHeight !== 0) {
		//   myChart.forceFit();
		// }
	});

	return <div id="chartBar" ref={myChartRef} style={{ height: '494px', width: '100%' }} />;
};

const MyLTopChartPie = ({ data, onMyLTopChartPie }) => {
	const myChartRef = useRef();
	// 图表
	const [myChart, setMyChart] = useState();

	// 加载图表数据
	useEffect(() => {
		var myChart = echarts.init(document.getElementById('chartLTopPie'), 'dark');

		// 绘制图表
		myChart.setOption({
			backgroundColor: '#fff',
			grid: {
				x: 5,
				y: 12,
				x2: 20,
				y2: 0,
			},
			legend: {
				orient: 'vertical', // 垂直排列
				top: 'center',
				right: 10,
				textStyle: {
					color: 'rgba(0, 0, 0, 0.85)', // 设置图例文字颜色为红色
				},
				data: data?.map((i) => ({ name: i.name, icon: 'circle' })),
				formatter: function (name) {
					return name.length > 7 ? name.slice(0, 7) + '...' : name;
				},
			},
			tooltip: {
				trigger: 'item',
				formatter: function (params) {
					return `纠纷类型<br/>${params.name}: ${params?.data?.caseNum}件（${params.value}%）`;
				},
			},
			series: [
				{
					name: '纠纷类型',
					type: 'pie',
					radius: '90%',
					center: ['30%', '50%'],
					color: ['#FCE996', '#FFCF8B', '#86E8DD', '#FDCDC5', '#C396ED', '#9FD4FD'],
					labelLine: {
						// 关闭引导线
						show: false,
					},
					label: {
						show: true,
						position: 'inside', // 设置文字在扇形区域内
						formatter: '{d}%', // 标签文本格式器
						rich: {
							a: {
								lineHeight: 25,
								align: 'center',
							},
							b: {
								lineHeight: 25,
								align: 'center',
							},
							c: {
								lineHeight: 25,
								align: 'center',
							},
							d: {
								lineHeight: 25,
								align: 'center',
							},
							e: {
								lineHeight: 25,
								align: 'center',
							},
							f: {
								lineHeight: 25,
								align: 'center',
							},
						},
						// normal: {
						//   show: false,
						// },
					},
					data: data,
				},
			],
		});
		// 移除旧的事件监听器
		myChart.off('click');

		//  为饼图添加点击事件
		myChart.on('click', onPieClick);

		// 事件处理函数
		function onPieClick(params) {
			onMyLTopChartPie(params);
		}
	}, [data]);

	return <div id="chartLTopPie" ref={myChartRef} style={{ height: '230px', width: '100%' }} />;
};

const MyLTopChartPie1 = ({ data, allNum }) => {
	const myChartRef = useRef();
	// 图表
	const [myChart, setMyChart] = useState();

	// 加载图表数据
	useEffect(() => {
		var myChart = echarts.init(document.getElementById('chartLTopPie1'), 'dark');
		// let data = [123, 98, 245, 234, 356, 148];
		// let dataAxis = ['低收入家庭', '单亲家庭', '流动家庭', '犯罪家庭', '无家庭', '其他']

		// 绘制图表
		myChart.setOption({
			backgroundColor: '#fff',
			grid: {
				x: 5,
				y: 12,
				x2: 20,
				y2: 0,
				containLabel: true,
			},
			legend: {
				orient: 'vertical', // 垂直排列
				top: 'center',
				right: 10,
				textStyle: {
					color: 'rgba(0, 0, 0, 0.85)', // 设置图例文字颜色为红色
				},
				data: [
					{
						name: '不予受理',
						icon: 'circle', // 图例标记的形状
					},
					{
						name: '化解中',
						icon: 'circle', // 图例标记的形状
					},
					{
						name: '化解成功',
						icon: 'circle',
					},
					{
						name: '化解不成功',
						icon: 'circle',
					},
				],
			},
			series: [
				{
					name: '化解状况',
					type: 'pie',
					radius: ['60%', '90%'], // 设置饼图的内半径和外半径，实现扇形区域
					center: ['30%', '50%'],
					color: ['#B6DDF1', '#5BA8E5', '#3A8AC6', '#094282'],
					data: data,
					label: {
						show: true,
						position: 'inside', // 设置文字在扇形区域内
						formatter: '{d}%', // 标签文本格式器
						rich: {
							a: {
								lineHeight: 25,
								align: 'center',
							},
							b: {
								lineHeight: 25,
								align: 'center',
							},
						},
					},
				},
			],
			graphic: {
				type: 'group',
				left: '22%',
				top: '45%',
				children: [
					{
						type: 'text',
						style: {
							text: '事件总数',
							fill: '#4E5969', // 第一部分文字颜色
							fontSize: 14,
							fontWeight: '400',
						},
					},
					{
						type: 'text',
						top: '24px',
						left: '15%',
						style: {
							text: allNum,
							fill: '#1D2129', // 第二部分文字颜色
							fontSize: 18,
							fontWeight: '400',
						},
					},
					{
						type: 'text',
						top: '28px',
						left: '55px',
						style: {
							text: '件',
							fill: '#86909C', // 第二部分文字颜色
							fontSize: 12,
							fontWeight: '400',
						},
					},
				],
			},
		});
	}, [data]);

	useEffect(() => {
		// if (myChart && myChartRef.current.clientHeight !== 0) {
		//   myChart.forceFit();
		// }
	});

	return <div id="chartLTopPie1" ref={myChartRef} style={{ height: '230px', width: '100%' }} />;
};
